build_cluster_eval_contexts

Function build_cluster_eval_contexts 

fn build_cluster_eval_contexts(
    catalog: &Catalog,
    filter: Option<&BTreeSet<ClusterId>>,
) -> Vec<ClusterEvalContext>
Build a ClusterEvalContext for each live cluster in the catalog, skipping clusters absent from filter when one is given.